@@ -190,7 +190,7 @@ class HamsterApplet(object):
                                           [("about", self.on_about),
                                           ("overview", self.show_overview),
                                           ("preferences", self.show_preferences),
-                                          ("help", self.on_more_info_button_clicked),
+                                          ("help", self.on_help_clicked),
                                           ])
 
         # load window of activity switcher and todays view
@@ -202,6 +202,10 @@ class HamsterApplet(object):
 
         self.new_name = widgets.ActivityEntry()
         self.new_name.connect("value-entered", self.on_switch_activity_clicked)
+
+        self.new_name.set_property("secondary-icon-name", "help")
+        self.new_name.connect("icon-press", self.on_more_info_button_clicked)
+
         widgets.add_hint(self.new_name, _("Activity"))
         self.get_widget("new_name_box").add(self.new_name)
         self.new_name.connect("changed", self.on_activity_text_changed)
@@ -332,50 +336,52 @@ class HamsterApplet(object):
 
         facts = runtime.storage.get_todays_facts()
 
-        self.treeview.detach_model()
-        self.treeview.clear()
-
         if facts and facts[-1]["end_time"] == None:
             self.last_activity = facts[-1]
         else:
             self.last_activity = None
 
-        if len(facts) > 15:
-            self._gui.get_object("today_box").set_size_request(-1, 360)
-            self._gui.get_object("today_box").set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_ALWAYS)
-        else:
-            self._gui.get_object("today_box").set_size_request(-1, -1)
-            self._gui.get_object("today_box").set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_NEVER)
 
-        by_category = {}
-        for fact in facts:
-            duration = 24 * 60 * fact["delta"].days + fact["delta"].seconds / 60
-            by_category[fact['category']] = \
-                          by_category.setdefault(fact['category'], 0) + duration
-            self.treeview.add_fact(fact)
+        if self.button.get_active():
+            self.treeview.detach_model()
 
-        self.treeview.attach_model()
 
-        if not facts:
-            self._gui.get_object("today_box").hide()
-            self._gui.get_object("fact_totals").set_text(_("No records today"))
-        else:
-            self._gui.get_object("today_box").show()
+            if len(facts) > 15:
+                self._gui.get_object("today_box").set_size_request(-1, 360)
+                self._gui.get_object("today_box").set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_ALWAYS)
+            else:
+                self._gui.get_object("today_box").set_size_request(-1, -1)
+                self._gui.get_object("today_box").set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_NEVER)
 
-            total_strings = []
-            for category in by_category:
-                # listing of today's categories and time spent in them
-                duration = locale.format("%.1f", (by_category[category] / 60.0))
-                total_strings.append(_("%(category)s: %(duration)s") % \
-                        ({'category': category,
-                          #duration in main drop-down per category in hours
-                          'duration': _("%sh") % duration
-                          }))
+            by_category = {}
+            for fact in facts:
+                duration = 24 * 60 * fact["delta"].days + fact["delta"].seconds / 60
+                by_category[fact['category']] = \
+                              by_category.setdefault(fact['category'], 0) + duration
+                self.treeview.add_fact(fact)
 
-            total_string = ", ".join(total_strings)
-            self._gui.get_object("fact_totals").set_text(total_string)
+            self.treeview.attach_model()
 
-        self.set_last_activity()
+            if not facts:
+                self._gui.get_object("today_box").hide()
+                self._gui.get_object("fact_totals").set_text(_("No records today"))
+            else:
+                self._gui.get_object("today_box").show()
+
+                total_strings = []
+                for category in by_category:
+                    # listing of today's categories and time spent in them
+                    duration = locale.format("%.1f", (by_category[category] / 60.0))
+                    total_strings.append(_("%(category)s: %(duration)s") % \
+                            ({'category': category,
+                              #duration in main drop-down per category in hours
+                              'duration': _("%sh") % duration
+                              }))
+
+                total_string = ", ".join(total_strings)
+                self._gui.get_object("fact_totals").set_text(total_string)
+
+            self.set_last_activity()
 
     def set_last_activity(self):
         activity = self.last_activity
@@ -396,8 +402,6 @@ class HamsterApplet(object):
                 self.get_widget("last_activity_name").set_text(activity['name'])
 
 
-            self._gui.get_object("more_info_button").hide()
-
             self.get_widget("last_activity_duration").set_text(stuff.format_duration(duration) or _("Just started"))
             self.get_widget("last_activity_description").set_text(activity['description'] or "")
             self.get_widget("activity_info_box").show()
@@ -410,8 +414,6 @@ class HamsterApplet(object):
             self.get_widget("last_activity_name").set_text(_("No activity"))
 
             self.get_widget("activity_info_box").hide()
-            self._gui.get_object("more_info_button").show()
-
             self.tag_box.draw([])
 
 
@@ -423,7 +425,7 @@ class HamsterApplet(object):
         """main window display and positioning"""
         self.button.set_active(is_active)
 
-        if not is_active:
+        if is_active == False:
             self.window.hide()
             return True
 
@@ -527,8 +529,8 @@ class HamsterApplet(object):
 
     """button events"""
     def on_overview(self, menu_item):
-        self.__show_toggle(False)
         dialogs.overview.show(self.applet)
+        self.__show_toggle(False)
 
     def show_overview(self, menu_item, verb):
         return self.on_overview(menu_item)
@@ -540,8 +542,8 @@ class HamsterApplet(object):
         dialogs.about.show(self.window)
 
     def show_preferences(self, menu_item, verb):
-        self.__show_toggle(False)
         dialogs.prefs.show(self.applet)
+        self.__show_toggle(False)
 
 
     """signals"""
@@ -696,5 +698,9 @@ class HamsterApplet(object):
         return self._gui.get_object(name)
 
     def on_more_info_button_clicked(self, *args):
+        gtk.show_uri(gtk.gdk.Screen(), "ghelp:hamster-applet#input", 0L)
+        return False
+
+    def on_help_clicked(self, *args):
         gtk.show_uri(gtk.gdk.Screen(), "ghelp:hamster-applet", 0L)
         return False
